ResourceManager

Struct ResourceManager 

pub struct ResourceManager { /* private fields */ }
Central storage of resources used in the game. Accessible from App by default.

For loading assets, you probably do not want to use this directly. In most cases, Assets should be used instead.

Cloning a ResourceManager will do a shallow copy, meaning copies will all use the same internal storage. You do not have to and should not wrap this type in an Rc.

See the module-level documentation for more information.

Implementations

Source

impl ResourceManager

pub fn allocate<T>(&self) -> ResourceHandle<T>

Allocates and returns a new ResourceHandle for the given type.

See the module-level documentation for more information.

pub fn set<T>(&self, handle: ResourceHandle<T>, data: T)

Sets the underlying value of the given ResourceHandle.

See the module-level documentation for more information.

pub fn get<T>(&self, handle: ResourceHandle<T>) -> Option<ResourceRef<T>>

Returns a reference to the underlying value of the given ResourceHandle.

Generally speaking, you should call this function again every time you need to access the data instead of keeping around the returned guard.

Panics

Panics if there is already a ResourceRef to the same resource.

See the module-level documentation for more information.