DrawRect

Struct DrawRect 

pub struct DrawRect<'a> { /* private fields */ }
A rectangle to be drawn.

This is a builder struct that allows you to specify extra parameters for the rectangle via method chaining. The rectangle is commited to the Graphics struct when DrawRect is dropped.

This struct is created using the draw_rect method on Graphics.

Implementations

Source

impl<'a> DrawRect<'a>

pub fn color(self, color: Color) -> Self

Sets the color of the rectangle.