DrawSprite

Struct DrawSprite 

pub struct DrawSprite<'a> { /* private fields */ }
A sprite to be drawn.

This is a builder struct that allows you to specify extra parameters for the sprite via method chaining. The sprite is commited to the Graphics struct when DrawSprite is dropped.

This struct is created using the draw_sprite method on Graphics.

Implementations

Source

impl<'a> DrawSprite<'a>

pub fn size(self, w: f32, h: f32) -> Self

Sets the size of the sprite.

pub fn source_pos(self, x: f32, y: f32) -> Self

Sets the source position of the sprite.

pub fn source_size(self, w: f32, h: f32) -> Self

Sets the source size of the sprite.

pub fn source_rect(self, x: f32, y: f32, w: f32, h: f32) -> Self

Sets the source rectangle of the sprite.

Equivalent to calling source_pos and then source_size.

pub fn color(self, color: Color) -> Self

Sets the color of the sprite.